package at.ac.wu.examples.java2d;

import javax.swing.*;
import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*; // BufferdImage
import java.net.URL;

import javax.imageio.*;
import java.io.*;

public class MyComponent extends JComponent {
	
	private BufferedImage buffer;
	private Image img;
	
	private int x_size, y_size;
	private int x_pos, y_pos;
	
	public MyComponent(int x_size, int y_size) {
		// set MyComponent's size
		this.x_size = x_size;
		this.y_size = y_size;
		
		// object start position
		this.x_pos = 0;
		this.y_pos = 0;
		this.setPreferredSize(
				new Dimension(x_size, y_size));
		this.setMaximumSize(
				new Dimension(x_size, y_size));
		this.setMinimumSize( 
				new Dimension(x_size, y_size));
		this.setDoubleBuffered(true);

		// load image
		try {
			// retrieve the image from the web
			// URL bildUrl = new URL("http://www.bugzilla.org/img/buggie.png");
			
			// or from the filesystem/jar file
			URL bildUrl = getClass().
				getResource("/at/ac/wu/examples/java2d/buggie.png");
			img = ImageIO.read( bildUrl );
		} catch (IOException e) {
			System.err.println(e);
		}
		
		
		// create buffer image 
		this.buffer = 
			new BufferedImage(x_size, y_size, 
					BufferedImage.TYPE_INT_RGB);
		this.setBackground(Color.GRAY);
	}
	
	
	protected void paintComponent(Graphics g) {
		super.paintComponent(g);
		Graphics2D g2d = (Graphics2D)g.create();
		g2d.drawImage(this.buffer, 0, 0, this);
		g2d.dispose(); // dispose handle (not required)
    }
	
	// control object movement
	public void moveNorth() { y_pos -=5; }
	public void moveSouth() { y_pos +=5; }
	public void moveEast()  { x_pos +=5; }
	public void moveWest() { x_pos -=5; }
	
	public void drawShapes() {
		Graphics2D g2d = this.buffer.createGraphics();
		g2d.clearRect( 0, 0, x_size, y_size);
		
		Ellipse2D.Double ellipse = 
			new Ellipse2D.Double(x_pos, y_pos, 80, 80);
		g2d.draw( ellipse );
		
		Rectangle2D.Double box = 
			new Rectangle2D.Double(x_pos+100, y_pos, 100, 80);
		g2d.fill( box );
		repaint();
	}
	
	public void drawImage() {
		Graphics2D g2d = this.buffer.createGraphics();
		g2d.clearRect( 0, 0, x_size, y_size);

		g2d.drawImage( img, x_pos, y_pos, null);
		repaint();
	}
	
}
